<?php
$lang['moddescription'] = 'This module adds the ability to include additional Meta data, Analytics tracking code and other useful SEO information.';
$lang['friendlyname'] = 'Meta Max';
$lang['postinstall'] = 'Be sure to set "Use Meta Max" permissions to use this module!';
$lang['postuninstall'] = 'Thanks! Come again soon.';
$lang['really_uninstall'] = 'Really? You\'re sure you want to uninstall this fine module?';
$lang['uninstalled'] = 'Module Uninstalled.';
$lang['installed'] = 'Module version %s installed.';
$lang['alert_no_records'] = 'No preferences have been set, please change and save your preferences before implementing MetaMax on your site.';
$lang['prefsupdated'] = 'Module preferences updated.';
$lang['submit'] = 'Save';
$lang['accessdenied'] = 'Access Denied. Please check your permissions.';
$lang['error'] = 'Error!';
$lang['analyticserror'] = 'Only one option can be checked at a time!';
$lang['none'] = 'None';
$lang['upgraded'] = 'Module upgraded to version %s.';
$lang['page_title_legend'] = 'Page title and description';
$lang['html_title_legend'] = 'HTML options';
$lang['css_title_legend'] = 'Stylesheet options';
$lang['jquery_title_legend'] = 'Jquery options';
$lang['additional_title_legend'] = 'Additional content';
$lang['meta_title_legend'] = 'Meta tags';
$lang['apple_title_legend'] = 'Apple Meta tags';
$lang['metaoptions_title_legend'] = 'Meta content';
$lang['keywords_title_legend'] = 'Keyword settings';
$lang['analytics_title_legend'] = 'Google Analytics settings';
$lang['search_title_legend'] = 'Google Analytics Search settings (All fields are required for this feature to work)';
$lang['bing_title_legend'] = 'Bing webmaster settings';
$lang['tab_mod_general'] = 'General settings';
$lang['tab_mod_html'] = 'HTML tag settings';
$lang['tab_mod_meta'] = 'Page title & Meta information';
$lang['tab_mod_css'] = 'Stylesheet settings';
$lang['tab_mod_jquery'] = 'JQuery settings';
$lang['tab_mod_keywords'] = 'Keyword settings';
$lang['tab_mod_analytics'] = 'Analytics Account settings';
$lang['tab_mod_bing'] = 'Bing Account settings';
$lang['page_smarty'] = 'Page title smarty tag';
$lang['page_smarty_help'] = 'This allows you to replace the standard current page title with a smarty tag';
$lang['page_title'] = 'Page title';
$lang['page_title_help'] = 'This will get appended to your page and site name';
$lang['delimiter_title'] = 'Page title delimiter';
$lang['delimiter_title_help'] = 'This is the symbol used to seperate your title text';
$lang['meta_block_title'] = 'Name of metadata content block';
$lang['meta_block_title_help'] = 'This should be the name given to your metadata content block, check module help for more info';
$lang['content_var_title'] = 'Content block variables';
$lang['content_var_title_help'] = 'A comma seperated list of variables';
$lang['block_title'] = 'Name of page description content block or variable';
$lang['canonical_block_title'] = 'Name of canonical content block';
$lang['block_title_help'] = 'This should be the name given to your page description content block, check module help for more info';
$lang['canonical_block_title_help'] = 'This should be the name given to your canonical link content block, check module help for more info';
$lang['length_title'] = 'Number of words to appear in auto description';
$lang['auto_title'] = 'Automatically generate a page description where none is provided';
$lang['base_title'] = 'Generate Base Tag';
$lang['baseslash_title'] = 'Add trailing slash to base URL?';
$lang['opendoctype_title'] = 'Generate Doctype tag';
$lang['doctype_title'] = 'Specify Doctype';
$lang['doctype_select'] = 'Please select one';
$lang['doctype_html5'] = 'HTML5';
$lang['doctype_xhtml_s'] = 'XHTML 1.0 Strict';
$lang['doctype_xhtml_t'] = 'XHTML 1.0 Transitional';
$lang['doctype_xhtml_f'] = 'XHTML 1.0 Frameset';
$lang['doctype_html4_s'] = 'HTML 4.01 Strict';
$lang['doctype_html4_t'] = 'HTML 4.01 Transitional';
$lang['doctype_html4_f'] = 'HTML 4.01 Frameset';
$lang['doctype_html4_rdf'] = 'HTML 4.01 + RDFa 1.1';
$lang['doctype_html3'] = 'HTML 3.2';
$lang['doctype_html2'] = 'HTML 2.0';
$lang['doctype_xhtml1'] = 'XHTML 1.1';
$lang['doctype_xhtml1_rdf'] = 'XHTML 1.1 + RDFa';
$lang['doctype_xhtml_rdf'] = 'XHTML + RDFa';
$lang['doctype_xhtml_basic_1_0'] = 'XHTML Basic 1.0';
$lang['doctype_xhtml_basic_1_1'] = 'XHTML Basic 1.1';
$lang['html_title'] = 'Specify HTML language (Possible use of smarty variable i.e &#123;$varIable})';
$lang['htmlextra_title'] = 'Extra HTML tag content';
$lang['htmlextra_title_help'] = 'Manifest information for example';
$lang['openhtml_title'] = 'Generate Opening HTML Tag';
$lang['xmlns_title'] = 'Include XMLNS';
$lang['dir_title'] = 'Include text direction';
$lang['dirchoice_title'] = 'Text direction';
$lang['dirchoice_select'] = 'Please select one';
$lang['dirchoice_ltr'] = 'Left to right';
$lang['dirchoice_rtl'] = 'Right to left';
$lang['lang_title'] = 'Include language';
$lang['xmllang_title'] = 'Include XML language';
$lang['openhead_title'] = 'Generate Opening Head Tag';
$lang['closehead_title'] = 'Generate Closing Head Tag';
$lang['compatible_title'] = 'Include X-UA-Compatible tag';
$lang['compatibleie_title'] = 'IE version for compatibility tag';
$lang['compatiblechrome_title'] = 'Chrome version for compatibility tag';
$lang['compatible_select'] = 'Please select one';
$lang['compatible_7'] = 'IE 7';
$lang['compatible_8'] = 'IE 8';
$lang['compatible_9'] = 'IE 9';
$lang['compatible_edge'] = 'IE Edge';
$lang['compatible_emulate7'] = 'Emulate IE 7';
$lang['compatible_chrome'] = 'Chrome';
$lang['additional_title'] = 'Additional content to appear in head';
$lang['stylesheet_title'] = 'Include &#123;cms_stylesheet} tag';
$lang['stylesheet_name'] = 'Name parameter';
$lang['stylesheet_nocombine'] = 'No Combine parameter';
$lang['stylesheet_nolinks'] = 'No Links parameter';
$lang['stylesheet_https'] = 'Use https url';
$lang['stylesheet_templateid'] = 'Template ID parameter';
$lang['stylesheet_media'] = 'Media parameter';
$lang['standard_title'] = 'Generate standard Meta Tags';
$lang['jquery_title'] = 'Include &#123;cms_jquery} tag';
$lang['jquery_exclude'] = 'Exclude parameter';
$lang['jquery_include'] = 'Include parameter';
$lang['jquery_cnd'] = 'CDN parameter';
$lang['jquery_ssl'] = 'SSL parameter';
$lang['jquery_custom_root'] = 'Custom root parameter';
$lang['jquery_assign'] = 'Assign parameter';
$lang['jquery_true'] = 'True';
$lang['jquery_false'] = 'False';
$lang['dublin_title'] = 'Generate Dublin Core Meta Tags';
$lang['opengraph_title'] = 'Generate OpenGraph Meta Tags (e.g. for Facebook Like Button)';
$lang['tweetme_title'] = 'Generate Tweetme title';
$lang['touchicon_root_title'] = 'Website Apple touch icon';
$lang['touchicon_root_title_help'] = 'Select an image from your root directory to be used as the Apple touch icon, should be 120px x 120px .png file';
$lang['touchicon_title'] = 'Website Apple touch icon';
$lang['touchicon_title_help'] = 'Select an image from your /uploads/images directory to be used as the Apple touch icon, should be 120px x 120px .png file';
$lang['drop_select'] = 'Please Select';
$lang['drop_yes'] = 'Yes';
$lang['drop_no'] = 'No';
$lang['style_select'] = 'Please Select';
$lang['style_default'] = 'default';
$lang['style_black'] = 'black';
$lang['style_translucent'] = 'black-translucent';
$lang['fullscreen_title'] = 'Full-screen mode';
$lang['statusbar_title'] = 'Status bar style';
$lang['phoneno_title'] = 'Phone number detection';
$lang['width_title'] = 'Viewport width, range is from 200 to 10,000 or device-width';
$lang['height_title'] = 'Viewport height, range is from 223 to 10,000 or device-height';
$lang['initial_title'] = 'Viewport initial scale';
$lang['minimum_title'] = 'Viewport minimum scale, range is from >0 to 10.0';
$lang['maximum_title'] = 'Viewport maximum scale, range is from >0 to 10.0';
$lang['scalable_title'] = 'Viewport user scalable';
$lang['robots_title'] = 'Robots meta tag';
$lang['robots_default'] = 'index, follow';
$lang['robots_1'] = 'noindex, follow';
$lang['robots_2'] = 'index, nofollow';
$lang['robots_3'] = 'noindex, nofollow';
$lang['publisher_title'] = 'Site publisher';
$lang['contributor_title'] = 'Site contributor';
$lang['relation_title'] = 'Related website';
$lang['email_title'] = 'Email';
$lang['phone_title'] = 'Phone number';
$lang['fax_title'] = 'Fax number';
$lang['street_title'] = 'Street address of your entity';
$lang['location_title'] = 'Location of your entity (Town, City)';
$lang['region_title'] = 'Region of your entity (State, County)';
$lang['postcode_title'] = 'Postal code of your entity';
$lang['country_title'] = 'Country of your entity';
$lang['latitude_title'] = 'Latitude of your entity';
$lang['longitude_title'] = 'Longitude of your entity';
$lang['ogtitle_title'] = 'OpenGraph page title';
$lang['ogtype_title'] = 'OpenGraph default page type';
$lang['ogtype_smarty_title'] = 'Smarty variable for page specific OpenGraph type';
$lang['ogtype_smarty_title_help'] = 'Useful in News and Blog articles where a more specific type may be preferred.';
$lang['ogname_title'] = 'OpenGraph site name';
$lang['ogimage_title'] = 'OpenGraph default image';
$lang['ogimage_title_help'] = 'Select an image from your /uploads/images directory to be used as the default for OpenGraph pages (200px x 200px)';
$lang['ogimage_smarty_title'] = 'Smarty variable for page specific OpenGraph image';
$lang['ogimage_smarty_title_help'] = 'Useful in News and Blog articles where a more specific image may be preferred.';
$lang['favicon_root_title'] = 'Website favicon';
$lang['favicon_root_title_help'] = 'Select an image from your root directory to be used as the site favicon, should be an .ico file';
$lang['favicon_title'] = 'Website favicon';
$lang['favicon_title_help'] = 'Select an image from your /uploads/images directory to be used as the site favicon, should be an .ico file';
$lang['favsize_title'] = 'Website favicon sizes';
$lang['favsize_title_help'] = 'Select your icon sizes if using multi-image ico file. i.e 16x16 32x32 64x64';
$lang['fbpage_title'] = 'Facebook page ID';
$lang['fbadmin_title'] = 'Facebook site administrators ID';
$lang['fbapp_title'] = 'Facebook application ID';
$lang['twittersite_title'] = 'Twitter ID';
$lang['twittersite_title_help'] = 'Your @ name. i.e @cmsms';
$lang['googleplus_title'] = 'Google Plus profile URL';
$lang['googleplus_title_help'] = 'Your Google Plus profile page URL. i.e https://plus.google.com/101806562165793532909/posts';
$lang['keywordson_title'] = 'Include keywords tag';
$lang['key_number'] = 'Number of keywords';
$lang['key_length'] = 'Length of keywords';
$lang['key_length_help'] = 'Minimum character length before becoming a keyword';
$lang['key_density'] = 'Density of keywords';
$lang['key_density_help'] = 'How many times a word has to appear before becoming a Keyword';
$lang['key_default'] = 'Set of default keywords to always include, comma seperated list';
$lang['key_smarty'] = 'Keyword smarty tag';
$lang['keyskip_title'] = 'Keyword STOP words';
$lang['key_stop_help'] = 'Words not to include as keywords, comma seperated list';
$lang['xml_title'] = 'Create an XML Google Sitemap';
$lang['push_title'] = 'Automatically push the sitemap to Google after content changes';
$lang['analytics_type'] = 'Anlytics type';
$lang['analytics_select'] = 'Please select one';
$lang['analytics_single'] = 'A single domain';
$lang['analytics_sub'] = 'One domain with multiple subdomains';
$lang['analytics_multiple'] = 'Multiple top-level domains';
$lang['analytics_universal'] = 'Universal Analytics';
$lang['analytics_help'] = 'If Universal Analytics is chosen Advertiser support option will be ignored';
$lang['analytics_support'] = 'Display Advertiser Support/Demographics and Interest reports tag?';
$lang['analytics_enhanced_link'] = 'Include enhanced link attribution tag?';
$lang['propertyid_title'] = 'Web Property ID (ie UA-XXXXXXXX-1)';
$lang['webmasterid_title'] = 'Webmaster meta verification key';
$lang['pretty_title'] = 'Are pretty URLs enabled?';
$lang['post_title'] = 'Search type POST being used?';
$lang['query_title'] = 'Query parameter';
$lang['query_help'] = 'This must be the same as the one entered in your Analytics account settings';
$lang['results_title'] = 'Results page alias';
$lang['results_help'] = 'Page alias of your search results page';
$lang['bingid_title'] = 'Bing verification ID';
$lang['changelog'] = '<ul>
<li>Version 1.0. 10 December 2011. Initial Release.</li>
<li>Version 1.1. 14 December 2011. Removed code that restricted description length when specifying page description rather than using the auto description feature.</li>
<li>Version 1.2. 14 December 2011. Fixed bug that threw errors on some servers.</li>
<li>Version 1.3. 14 December 2011. Added the ability to use a smarty tag as the current page title.</li>
<li>Version 1.4. 15 December 2011. Added Bing webmaster tab.</li>
<li>Version 1.5. 16 December 2011. Added HTML and Doctype controls.</li>
<li>Version 1.6. 19 December 2011. Merged Google and Bing tabs and added the ability to specify keyword stop words.</li>
<li>Version 1.6.1. 19 December 2011. Minor bug fix.</li>
<li>Version 1.6.2. 21 December 2011. Added more HTML tag controls.</li>
<li>Version 1.6.3. 21 December 2011. Added X-UA-Compatability Meta tag and controls.</li>
<li>Version 1.6.4. 25 January 2012. Bug fix #7513 as suggested by Stephen Owens.</li>
<li>Version 1.6.5. 27 January 2012. Removed error if no text appears in the page content area.</li>
<li>Version 1.6.6. 31 January 2012. Added Analytics search options.</li>
<li>Version 1.6.7. 22 February 2012. Bug fixes and addition of Metadata content block to enable page specific metadata.</li>
<li>Version 1.6.8. 24 February 2012. Minor bug fix.</li>
<li>Version 1.6.9. 25 February 2012. Bug fix #7638 and #7639.</li>
<li>Version 1.6.9.1. 25 February 2012. Made PHP 5.2 compatible to fix bug #7638.</li>
<li>Version 1.7 26 February 2012. Added the ability to specify multiple content blocks from where pages keywords and descriptions are created from assigned variables.</li>
<li>Version 1.7.1 26 February 2012. Minor bug fix.</li>
<li>Version 1.7.2 26 February 2012. Minor bug fix.</li>
<li>Version 1.7.3 27 February 2012. Added seperate cms_stylesheet and cms_jquery tabs.</li>
<li>Version 1.7.3.1 27 February 2012. Minor bug fix.</li>
<li>Version 1.7.4 27 February 2012. Minor bug fixes and removed non working stylesheet and jquery params to avoid confusion.</li>
<li>Version 1.7.4.1 29 February 2012. Minor bug fix and the addition of smarty use in the language field, useful for mulitlingual sites.</li>
<li>Version 1.7.4.2 29 February 2012. Added the ability to display Apple meta tags.</li>
<li>Version 1.7.4.3 1 March 2012. Minor bug fix.</li>
<li>Version 1.7.4.4 5 March 2012. Added Favicon and Apple Touch Icon options.</li>
<li>Version 1.7.4.6 6 March 2012. Removed invalid meta tags if HTML5 is chosen.</li>
<li>Version 1.7.4.7 15 March 2012. Added canonical link.</li>
<li>Version 1.7.4.8 3 April 2012. Added favicon size option for use with multi-image ico files.</li>
<li>Version 1.7.4.9 18 May 2012. Stripping out of whitespace from descriptions added.</li>
<li>Version 1.7.5 21 June 2012. Bug fix for 1.11 compatability.</li>
<li>Version 1.7.6 4 July 2012. Additional optional meta tags added, Street, Postalcode, Country, Email, Telephone, Fax, Facebook page ID and Tweetme title. Minor bug fixes.</li>
<li>Version 1.7.6.1 11 July 2012. Added IE7 Emulate option to X-UA-Compatible tag.</li>
<li>Version 1.7.7 9 October 2012. Additional HTML block now accepts smarty.</li>
<li>Version 1.7.8 6 November 2012. Fixed issue where canonical link for news articles showed default detail page URL rather than news story URL.</li>
<li>Version 1.7.9 26 November 2012. Added the ability to use CMSMS page specific metadata field instead of adding content block to your templates.</li>
<li>Version 1.7.9.1 27 November 2012. Stopped default holding meta text appearing.</li>
<li>Version 1.8 18 December 2012. Canonical link bug fix.</li>
<li>Version 1.9.1 4 February 2013. Minor bug fix.</li>
<li>Version 1.9.2 5 February 2013. Template update and addition of OpenGraph image smarty call to specify non default OpenGraph image, suggested by Gregor.</li>
<li>Version 1.9.3 25 February 2013. Added the option to specify canonical links per page using in content block, also added a Display Advertiser Support option to the analytics tab.</li>
<li>Version 1.9.4 21 March 2013. Added the options to choose Apple Touch and Fav icons from the website root directory.</li>
<li>Version 1.9.6 11 April 2013. Added the option to choose robots meta and Twitter card and Google+ profile page links.</li>
<li>Version 1.9.7 18 April 2013. Content block variables now appear in order in the description tag, appended by the content of the default Content block by default.</li>
<li>Version 1.9.8 22 April 2013. Added support for Google Universal Analytics.</li>
<li>Version 1.9.9 30 April 2013. Added the ability to disable/enable keywords tag.</li>
<li>Version 1.9.9.1 2 May 2013. Minor bug fixes.</li>
<li>Version 1.9.9.2 25 June 2013. Stripped files appended with thumb_ from image dropdowns. Added process_pagedata tag to MetaMax output, making the Meta Data field redundant.</li>
<li>Version 1.9.9.3 30 July 2013. Added trailing slash option for base tag, plus minor language updates spotted by Velden.</li>
<li>Version 1.9.9.4 11 November 2013. Added option to include Demographics and Interest Reports tag into Analytics code.</li>
<li>Version 1.9.9.5 20 November 2013. Added option to include enhanced link attribution tag into Analytics code.</li>
<li>Version 1.9.9.6 18 February 2014. Minor bug fix for https urls.</li>
<li>Version 1.9.9.7 13 May 2014. Added additional Twitter meta tags plus minor cleaning up.</li>
<li>Version 1.9.9.8 17 June 2014. Added addition default keyword skip words and made county and country fields accept more than 5 chars.</li>
<li>Version 1.9.9.9 17 July 2014. Amend to GA Universal tracking code.</li>
<li>Version 2.0 12 August 2014. Added the ability to specify keywords content block to append keywords per page. Minor bug fixes.</li>
<li>Version 2.1 21 August 2014. Minor bug fix.</li>
<li>Version 2.1.1 26 August 2014. Minor HTML5 bug fix.</li>
<li>Version 2.1.2 14 October 2014. Minor bug fix.</li>
<li>Version 2.1.3 27 October 2014. Compatability with CMSMS v2. Minor updates and bug fixes. Added the ability to get description from smarty varaible.</li>
<li>Version 2.1.3.1 27 October 2014. Minor compatability fix.</li>
<li>Version 2.1.3.2 29 October 2014. Minor bug fix.</li>
<li>Version 2.1.3.3 2 December 2014. Minor bug fix where auto description may not have worked in certain circumstances.</li>
</ul>';
$lang['help'] = '<h3>What Does This Do?</h3>
<p>This module adds the ability to include additional Meta data, Analytics tracking code and other useful SEO information. It can also be used to generate Doctype and Head tags, replacing the entire head of your document.</p>
<h3>How Do I Use It</h3>
<p>Meta Max can be used either to add additional meta data to your templates by inserting the call into the head section, or completely replace the head code in your templates.</p>
<p>Meta Max has the ability to generate opening HTML tags, Doctype tag and everything you could need in your Head tags too.</p>
<p>Firstly you need to remove the standard &#123;metadata} call, this is not compatible with Meta Max and may cause problems. You may also need to remove your <DOCTYPE>, opening <html> tag and <head> tags depending on which parameters you have enabled.</p>
<p>Just add &#123;MetaMax} to the top or head of each template.</p>
<p>If you are using the auto description option you will need to add &#123;capture}&#123;content block=\'Page Description\' oneline=\'true\' wysiwyg=\'false\'}&#123;/capture} to your templates and reference this content blocks name in the \'page description content block\' input field, which in this example is Page Description.</p>
<p>If you want page specific metadata simply add &#123;capture}&#123;content block=\'Metadata\' wysiwyg=\'false\'}&#123;/capture} to your templates and reference this content blocks name in the \'metadata content block\' input field, which in this example is Metadata. Similar setup for the page description and canonical link options. Canonical links need the full URL, i.e http://www.cmsmadesimple.org</p>
<p>The Analytics search options are only required if you are using pretty URL\'s in conjunction with the search module\'s POST method otherwise simply adding the default cntnt01searchinput into your Analytics setup will track site search queries.</p>
<p>There are more examples and instructions available at https://sites.google.com/site/metamaxwiki/ please feel free to contribute any examples and findings you have.</p>
<h3>Support</h3>
<p>This module does not include commercial support. However, there are a number of resources available to help you with it:</p>
<ul>
<li>For the latest version of this module, FAQs, or to file a Bug Report, please visit the Module Forge
<a href="http://dev.cmsmadesimple.org/projects/metamax/">Meta Max Page</a>.</li>
<li>Additional discussion of this module may also be found in the <a href="http://forum.cmsmadesimple.org">CMS Made Simple Forums</a>.</li>
<li>The author, oliverseddon, can often be found in the <a href="irc://irc.freenode.net/#cms">CMS IRC Channel</a>.</li>
<li>Lastly, you may have some success emailing the author directly.</li>  
</ul>
<p>As per the GPL, this software is provided as-is. Please read the text
of the license for the full disclaimer.</p>

<h3>Copyright and License</h3>
<p>Copyright &copy; 2012, Oliver Seddon <a href="mailto:oliver@threefold.co.uk">&lt;oliver@threefold.co.uk&gt;</a>. All Rights Are Reserved.</p>
<p>This module has been released under the <a href="http://www.gnu.org/licenses/licenses.html#GPL">GNU Public License</a>. You must agree to this license before using the module.</p>
';
?>